#from http://www.ladyada.net/library/i2caddr.html
sensors={
0x0:['Could be MLX90614. Try 0x5A'],
0x13:['VCNL4000'],
0x3c:['OLED SSD1306',],
0x3d:['OLED SSD1306',],
0x48:['PN532 RFID'],
0x29:['TSL2561'],
0x39:['TSL2561'],
0x49:['TSL2561'],
0x1D:['ADXL345','MMA7455L','LSM9DSO'],
0x53:['ADXL345'],
0x5A:['MLX90614 PIR temperature'],
0x1E:['HMC5883L magnetometer','LSM303 magnetometer'],
0x77:['BMP180/GY-68 altimeter','MS5607','MS5611'],
0x68:['MPU-6050/GY-521 accel+gyro+temp','ITG3200','DS1307','DS3231'],
0x69:['ITG3200'],
0x76:['MS5607','MS5611'],
0x6B:['LSM9DSO gyro'],
0x19:['LSM303 accel'],
0x20:['MCP23008','MCP23017'],
0x21:['MCP23008','MCP23017'],
0x22:['MCP23008','MCP23017'],
0x23:['BH1750','MCP23008','MCP23017'],
0x24:['MCP23008','MCP23017'],
0x25:['MCP23008','MCP23017'],
0x26:['MCP23008','MCP23017'],
0x27:['MCP23008','MCP23017'],
0x40:['SHT21(Temp/RH)'],
0x60:['MCP4725A0 4 chan DAC (onBoard)'],
0x61:['MCP4725A0 4 chan DAC'],
0x62:['MCP4725A1 4 chan DAC'],
0x63:['MCP4725A1 4 chan DAC','Si4713'],
0x64:['MCP4725A2 4 chan DAC'],
0x65:['MCP4725A2 4 chan DAC'],
0x66:['MCP4725A3 4 chan DAC'],
0x67:['MCP4725A3 4 chan DAC'],
0x11:['Si4713'],
0x38:['FT6206 touch controller'],
0x41:['STMPE610'],

}


